@@ -1,22 +1,20 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="sk">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk" version="2.1">
 <context>
     <name>CustomDialog</name>
     <message>
-        <location filename="../dialog.cpp" line="15"/>
+        <location filename="dialog.cpp" line="15"/>
         <source>Live environment detected. Please select the root partition of the
  system you want to modify (only Linux partitions are displayed)</source>
         <translation>Bolo rozpoznané prostredie Live. Prosím zvoľte diskový oddiel root
 systému, ktorý chcete upraviť (zobrazené sú iba Linuxové oddiely)</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="22"/>
+        <location filename="dialog.cpp" line="22"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../dialog.cpp" line="23"/>
+        <location filename="dialog.cpp" line="23"/>
         <source>Cancel</source>
         <translation>Zrušiť</translation>
     </message>
@@ -24,366 +22,372 @@ systému, ktorý chcete upraviť (zobrazené sú iba Linuxové oddiely)</transla
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.ui" line="32"/>
+        <location filename="mainwindow.ui" line="32"/>
         <source>Options</source>
         <translation>Nastavenia</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="38"/>
+        <location filename="mainwindow.ui" line="38"/>
         <source>Kernel parameters</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="58"/>
+        <location filename="mainwindow.ui" line="58"/>
         <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
         <translation>Pre zavedenie systému bez zobrazenia menu zvoľte &apos;0&apos;, pre zobrazenie bez odpočtu &apos;-1&apos;</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="61"/>
+        <location filename="mainwindow.ui" line="61"/>
         <source>Menu timeout</source>
         <translation>Odpočet menu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="74"/>
+        <location filename="mainwindow.ui" line="74"/>
         <source>Boot to</source>
         <translation>Zaviesť</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="81"/>
+        <location filename="mainwindow.ui" line="81"/>
         <source>Use simplified menu structure without submenus</source>
         <translation>Použit zjednodušené menu bez dielčích ponúk</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="84"/>
+        <location filename="mainwindow.ui" line="84"/>
         <source>Use flat menus (no submenus)</source>
         <translation>Použiť ploché menu (bez dielčích ponúk)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="113"/>
+        <location filename="mainwindow.ui" line="113"/>
         <source>seconds</source>
         <translation>sekúnd</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="120"/>
+        <location filename="mainwindow.ui" line="120"/>
         <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
         <translation>Pri tejto voľbe, čokoľvek vyberiete pri prvom zavedení bude nastavené ako predvolené pre ďalšie štarty systému </translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="123"/>
+        <location filename="mainwindow.ui" line="123"/>
         <source>Enable saving last boot choice</source>
         <translation>Povoliť ukladanie poslednej voľby zavedenia systému</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="136"/>
+        <location filename="mainwindow.ui" line="136"/>
         <source>Background</source>
         <translation>Pozadie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="154"/>
+        <location filename="mainwindow.ui" line="154"/>
         <source>Image</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="167"/>
-        <location filename="../mainwindow.ui" line="269"/>
+        <location filename="mainwindow.ui" line="167"/>
+        <location filename="mainwindow.ui" line="269"/>
         <source>Enable theme</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="247"/>
+        <location filename="mainwindow.ui" line="247"/>
         <source>Splash</source>
         <translation>Splash</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="282"/>
+        <location filename="mainwindow.ui" line="282"/>
         <source>Preview</source>
         <translation>Náhľad</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="305"/>
+        <location filename="mainwindow.ui" line="305"/>
         <source>Messages</source>
         <translation>Zprávy</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="311"/>
+        <location filename="mainwindow.ui" line="311"/>
         <source>Very detailed</source>
         <translation>Veľmi podrobne</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="318"/>
+        <location filename="mainwindow.ui" line="318"/>
         <source>Detailed (default setting)</source>
         <translation>Detailne (predvolené nastavenie)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="328"/>
+        <location filename="mainwindow.ui" line="328"/>
         <source>Limited</source>
         <translation>Obmedzené</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="344"/>
+        <location filename="mainwindow.ui" line="344"/>
         <source>Display log</source>
         <translation>Zobraziť záznam</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="397"/>
+        <location filename="mainwindow.ui" line="397"/>
         <source>Display help </source>
         <translation>Zobraziť nápovedu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="400"/>
+        <location filename="mainwindow.ui" line="400"/>
         <source>Help</source>
         <translation>Pomocník</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="407"/>
+        <location filename="mainwindow.ui" line="407"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="439"/>
+        <location filename="mainwindow.ui" line="439"/>
         <source>About this application</source>
         <translation>O tejto aplikácii</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="442"/>
+        <location filename="mainwindow.ui" line="442"/>
         <source>About...</source>
         <translation>O Programe</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="449"/>
+        <location filename="mainwindow.ui" line="449"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="484"/>
+        <location filename="mainwindow.ui" line="484"/>
         <source>Quit application</source>
         <translation>Zatvoriť aplikáciu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="487"/>
-        <location filename="../mainwindow.cpp" line="692"/>
+        <location filename="mainwindow.ui" line="487"/>
+        <location filename="mainwindow.cpp" line="665"/>
         <source>Close</source>
         <translation>Zatvoriť</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="494"/>
+        <location filename="mainwindow.ui" line="494"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="535"/>
+        <location filename="mainwindow.ui" line="535"/>
         <source>Apply</source>
         <translation>Použiť</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="67"/>
+        <location filename="mainwindow.cpp" line="66"/>
         <source>Still running</source>
         <translation>Stále spustené</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="67"/>
+        <location filename="mainwindow.cpp" line="66"/>
         <source>Process still running. Are you sure you want to quit?</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="168"/>
+        <location filename="mainwindow.cpp" line="163"/>
         <source>Installing bootsplash, please wait</source>
         <translation>Inštalácia bootsplash, prosím čakajte</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="175"/>
+        <location filename="mainwindow.cpp" line="170"/>
         <source>Updating sources</source>
         <translation>Aktualizácia zdrojov</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="177"/>
+        <location filename="mainwindow.cpp" line="172"/>
         <source>Installing</source>
         <translation>Inštalácia</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="181"/>
-        <location filename="../mainwindow.cpp" line="327"/>
+        <location filename="mainwindow.cpp" line="176"/>
+        <location filename="mainwindow.cpp" line="318"/>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="181"/>
+        <location filename="mainwindow.cpp" line="176"/>
         <source>Could not install the bootsplash.</source>
         <translation>Nepodarilo sa nainštalovať bootsplash.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="283"/>
-        <location filename="../mainwindow.cpp" line="333"/>
+        <location filename="mainwindow.cpp" line="274"/>
+        <location filename="mainwindow.cpp" line="324"/>
         <source>Cannot continue</source>
         <translation>Nedá sa pokračovať</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="283"/>
+        <location filename="mainwindow.cpp" line="274"/>
         <source>Nothing was selected, cannot change boot options. Exiting...</source>
         <translation>Nič nebolo vybrané, žiadne zmeny v nastavení zavedenia. Ukončovanie...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="328"/>
+        <location filename="mainwindow.cpp" line="319"/>
         <source>Could not create a temporary folder</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="333"/>
+        <location filename="mainwindow.cpp" line="324"/>
         <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
         <translation>Nejde vytvoriť chroot prostredie, žiadne zmeny v nastavení zavedenia. Ukončovanie...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="582"/>
-        <location filename="../mainwindow.cpp" line="896"/>
+        <location filename="mainwindow.cpp" line="561"/>
+        <location filename="mainwindow.cpp" line="857"/>
         <source>Updating configuration, please wait</source>
         <translation>Aktualizácia konfigurácie, prosím čakajte</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="633"/>
+        <location filename="mainwindow.cpp" line="608"/>
         <source>Updating initramfs...</source>
         <translation>Aktualizácia initramfs...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="643"/>
-        <location filename="../mainwindow.cpp" line="909"/>
+        <location filename="mainwindow.cpp" line="617"/>
+        <location filename="mainwindow.cpp" line="869"/>
         <source>Updating grub...</source>
         <translation>Aktualizácia GRUBu...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="647"/>
+        <location filename="mainwindow.cpp" line="621"/>
         <source>Done</source>
         <translation>Hotovo</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="647"/>
+        <location filename="mainwindow.cpp" line="621"/>
         <source>Changes have been successfully applied.</source>
         <translation>Zmeny boli prevedené.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="660"/>
+        <location filename="mainwindow.cpp" line="634"/>
         <source>About</source>
         <translation>O Programe</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="661"/>
+        <location filename="mainwindow.cpp" line="635"/>
         <source>Version: </source>
         <translation>Verzia:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="662"/>
+        <location filename="mainwindow.cpp" line="636"/>
         <source>Program for selecting common start-up choices</source>
         <translation>Program pre výber z volieb zavedenia systému</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="664"/>
+        <location filename="mainwindow.cpp" line="638"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="665"/>
-        <location filename="../mainwindow.cpp" line="675"/>
+        <location filename="mainwindow.cpp" line="639"/>
+        <location filename="mainwindow.cpp" line="649"/>
         <source>License</source>
         <translation>Licencia</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="666"/>
-        <location filename="../mainwindow.cpp" line="681"/>
+        <location filename="mainwindow.cpp" line="640"/>
+        <location filename="mainwindow.cpp" line="654"/>
         <source>Changelog</source>
         <translation>História zmien</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="667"/>
+        <location filename="mainwindow.cpp" line="641"/>
         <source>Cancel</source>
         <translation>Zrušiť</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="711"/>
+        <location filename="mainwindow.cpp" line="684"/>
         <source>MX Boot Options</source>
         <translation>MX Možnosti zavedenia</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="723"/>
+        <location filename="mainwindow.cpp" line="695"/>
         <source>Running in a Virtual Machine</source>
         <translation>Spustené vo Virtuálnej Mašine</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="724"/>
+        <location filename="mainwindow.cpp" line="696"/>
         <source>You current system is running in a Virtual Machine,
 Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
         <translation>Váš systém beží vo Virtuálnej Mašine,
 Plymouth bootsplash bude fungovať v obmedzenej miere, taktiež nebude možné zobraziť náhľad</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="729"/>
+        <location filename="mainwindow.cpp" line="701"/>
         <source>Plymouth packages not installed</source>
         <translation>Plymouth nie je nainštalované</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="729"/>
+        <location filename="mainwindow.cpp" line="701"/>
         <source>Plymouth packages are not currently installed.
 OK to go ahead and install them?</source>
         <translation>Plymouth nie je nainštalované.
 Prajete si ho nainštalovať?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="750"/>
+        <location filename="mainwindow.cpp" line="721"/>
         <source>Images (*.png *.jpg *.jpeg *.tga)</source>
         <translation>Orázky (*.png *.jpg *.jpeg *.tga)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="859"/>
+        <location filename="mainwindow.cpp" line="823"/>
         <source>Press any key to close</source>
         <translation>Pre ukončenie stlačte ľubovoľnú klávesu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="861"/>
+        <location filename="mainwindow.cpp" line="825"/>
         <source>Log not found</source>
         <translation>Záznam nebol nájdený</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="861"/>
+        <location filename="mainwindow.cpp" line="825"/>
         <source>Could not find log at </source>
         <translation>Záznam nie je na</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="875"/>
+        <location filename="mainwindow.cpp" line="838"/>
         <source>Needs reboot</source>
         <translation>Je potrebný reštart PC</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="875"/>
+        <location filename="mainwindow.cpp" line="838"/>
         <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
         <translation>Plymouth bolo nainštalované, pre zobrazenie náhľadov možno bude potrebné reštartovať PC</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="931"/>
+        <location filename="mainwindow.cpp" line="891"/>
         <source>Click to select theme</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>QApplication</name>
     <message>
-        <source>You must run this program as root.</source>
-        <translation type="vanished">Tento program musíte spustiť ako root užívateľ.</translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="42"/>
+        <location filename="main.cpp" line="42"/>
         <source>Program for selecting common start-up choices</source>
-        <translation type="unfinished">Program pre výber z volieb zavedenia systému</translation>
+        <translation>Program pre výber z volieb zavedenia systému</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../mainwindow.cpp" line="749"/>
+        <location filename="main.cpp" line="61"/>
+        <source>Error</source>
+        <translation>Chyba</translation>
+    </message>
+    <message>
+        <location filename="main.cpp" line="62"/>
+        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="720"/>
         <source>Select image to display in bootloader</source>
         <translation>Vybrať obrázok pre bootloader</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="941"/>
+        <location filename="mainwindow.cpp" line="901"/>
         <source>Select GRUB theme</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
